import type { Address, AddressPatch } from '.';
export type HasAddress = {
    /**
     * Адрес склада
     *
     * Строка адреса является конкатенацией полей структурированного адреса в
     * следующем порядке:
     *
     * `postalCode` -> `country` -> `region` -> `city` -> `street` -> `house` ->
     * `apartment` -> `addInfo`, используя запятую в качестве разделителя.
     *
     * При передаче в МойСклад сущностей с адресом используйте либо строковый
     * адрес, либо структурированный.
     *
     * При передаче обоих адресов строковый будет игнорирован.
     *
     * При передаче только строкового он будет отражаться как в строковом поле
     * так и в addInfo структурированного адреса.
     *
     * Для адреса не поддерживается значение `null`. Передача `null` этому аттрибуту
     * не приведет к его удалению. Для удаления адреса необходимо в строковое поле
     * address передать пустую строку "".
     */
    address: string;
    /**
     * Адрес с детализацией по отдельным полям.
     */
    addressFull?: Address;
};
export type HasAddressPatch = {
    address?: string;
    /**
     * Адрес с детализацией по отдельным полям.
     */
    addressFull?: AddressPatch;
};
